Index: boost/program_options/detail/value_semantic.hpp
===================================================================
--- boost/program_options/detail/value_semantic.hpp	(revision 80990)
+++ boost/program_options/detail/value_semantic.hpp	(working copy)
@@ -11,7 +11,7 @@
 namespace boost { namespace program_options { 
 
     extern BOOST_PROGRAM_OPTIONS_DECL std::string arg;
-    
+ 
     template<class T, class charT>
     std::string
     typed_value<T, charT>::name() const
@@ -86,7 +86,7 @@
         validators::check_first_occurrence(v);
         std::basic_string<charT> s(validators::get_single_string(xs));
         try {
-            v = any(lexical_cast<T>(s));
+            v = any(detail::convert_to<T>(s));
         }
         catch(const bad_lexical_cast&) {
             boost::throw_exception(invalid_option_value(s));
Index: boost/program_options/value_semantic.hpp
===================================================================
--- boost/program_options/value_semantic.hpp	(revision 80990)
+++ boost/program_options/value_semantic.hpp	(working copy)
@@ -12,6 +12,8 @@
 #include <boost/any.hpp>
 #include <boost/function/function1.hpp>
 #include <boost/lexical_cast.hpp>
+#include <boost/optional/optional_fwd.hpp>
+#include <boost/type_traits/integral_constant.hpp>
 
 
 #include <string>
@@ -20,6 +22,38 @@
 
 namespace boost { namespace program_options {
 
+	namespace detail {	
+
+		template<class T>
+		struct is_optional : false_type {
+		};
+
+  		template<class T>
+		struct is_optional<optional<T> > : true_type {
+		};
+
+		template<class To, class From>
+		To convert_to_impl(From const& v, false_type, false_type) {
+			return lexical_cast<To>(v);
+		};
+
+		template<class To, class From>
+		To convert_to_impl(From const& v, false_type, true_type) {
+			return lexical_cast<To>(*v);
+		};
+
+		template<class To, class From>
+		To convert_to_impl(From const& v, true_type, false_type) {
+			return lexical_cast<typename To::value_type>(v);
+		};
+
+		template<class To, class From>
+		To convert_to(From const& v) {
+			return convert_to_impl<To>(v, is_optional<To>(), is_optional<From>());
+		}
+
+	}
+
     /** Class which specifies how the option's value is to be parsed
         and converted into C++ types.
     */
@@ -195,7 +229,7 @@
         typed_value* default_value(const T& v)
         {
             m_default_value = boost::any(v);
-            m_default_value_as_text = boost::lexical_cast<std::string>(v);
+            m_default_value_as_text = detail::convert_to<std::string>(v);
             return this;
         }
 
@@ -223,7 +257,7 @@
         {
             m_implicit_value = boost::any(v);
             m_implicit_value_as_text =
-                boost::lexical_cast<std::string>(v);
+                detail::convert_to<std::string>(v);
             return this;
         }
 
